/*
 * Copyright Debezium Authors.
 *
 * Licensed under the Apache Software License version 2.0, available at http://www.apache.org/licenses/LICENSE-2.0
 */
package io.debezium.schema;

import java.util.Properties;

import io.debezium.common.annotation.Incubating;
import io.debezium.config.CommonConnectorConfig;
import io.debezium.spi.schema.DataCollectionId;

/**
 * Implement a unicode converter strategy to determine data event topic names using {@link DataCollectionId#schemaParts()}.
 *
 * @author Harvey Yue
 */
@Incubating
public class SchemaUnicodeTopicNamingStrategy extends AbstractUnicodeTopicNamingStrategy {

    public SchemaUnicodeTopicNamingStrategy(Properties props) {
        super(props);
    }

    public static SchemaUnicodeTopicNamingStrategy create(CommonConnectorConfig config) {
        return new SchemaUnicodeTopicNamingStrategy(config.getConfig().asProperties());
    }

    @Override
    public String dataChangeTopic(DataCollectionId id) {
        return topicNames.computeIfAbsent(id, t -> sanitizedTopicName(getSchemaPartsTopicName(id)));
    }
}
